summaryrefslogtreecommitdiff
path: root/usr.bin/make
diff options
context:
space:
mode:
authorMarc Espie <espie@cvs.openbsd.org>2007-11-03 11:44:31 +0000
committerMarc Espie <espie@cvs.openbsd.org>2007-11-03 11:44:31 +0000
commitdd1faad1394d7a5aacdef8215f7833ca9e8c5b65 (patch)
tree29a732e27c362035f2a90136aa4f5468d0f6ce89 /usr.bin/make
parent4a2dd3cefc94c377b9fc553c556e53311f106a00 (diff)
token is a confusing name, rename to banner
Diffstat (limited to 'usr.bin/make')
-rw-r--r--usr.bin/make/defines.h4
-rw-r--r--usr.bin/make/job.c24
-rw-r--r--usr.bin/make/main.c4
3 files changed, 16 insertions, 16 deletions
diff --git a/usr.bin/make/defines.h b/usr.bin/make/defines.h
index e2cb2181ac3..1d668fabc1f 100644
--- a/usr.bin/make/defines.h
+++ b/usr.bin/make/defines.h
@@ -2,7 +2,7 @@
#define DEFINES_H
/* $OpenPackages$ */
-/* $OpenBSD: defines.h,v 1.4 2007/11/02 17:27:24 espie Exp $ */
+/* $OpenBSD: defines.h,v 1.5 2007/11/03 11:44:30 espie Exp $ */
/*
* Copyright (c) 2001 Marc Espie.
@@ -89,7 +89,7 @@ extern int debug;
#define DEBUG_VAR 0x0200
#define DEBUG_FOR 0x0400
#define DEBUG_LOUD 0x0800
-#define DEBUG_JOBTOKEN 0x1000
+#define DEBUG_JOBBANNER 0x1000
#define CONCAT(a,b) a##b
diff --git a/usr.bin/make/main.c b/usr.bin/make/main.c
index ef2ef8dde6b..785ba835144 100644
--- a/usr.bin/make/main.c
+++ b/usr.bin/make/main.c
@@ -1,5 +1,5 @@
/* $OpenPackages$ */
-/* $OpenBSD: main.c,v 1.87 2007/11/02 17:27:24 espie Exp $ */
+/* $OpenBSD: main.c,v 1.88 2007/11/03 11:44:30 espie Exp $ */
/* $NetBSD: main.c,v 1.34 1997/03/24 20:56:36 gwr Exp $ */
/*
@@ -259,7 +259,7 @@ MainParseArgs(int argc, char **argv)
debug |= DEBUG_JOB;
break;
case 'J':
- debug |= DEBUG_JOBTOKEN;
+ debug |= DEBUG_JOBBANNER;
break;
case 'l':
debug |= DEBUG_LOUD;
diff --git a/usr.bin/make/job.c b/usr.bin/make/job.c
index d730c0d5605..a7384441a0d 100644
--- a/usr.bin/make/job.c
+++ b/usr.bin/make/job.c
@@ -1,5 +1,5 @@
/* $OpenPackages$ */
-/* $OpenBSD: job.c,v 1.104 2007/11/03 10:41:48 espie Exp $ */
+/* $OpenBSD: job.c,v 1.105 2007/11/03 11:44:30 espie Exp $ */
/* $NetBSD: job.c,v 1.16 1996/11/06 17:59:08 christos Exp $ */
/*
@@ -240,7 +240,7 @@ static void JobRestartJobs(void);
static void debug_printf(const char *, ...);
static Job *prepare_job(GNode *, int);
static void start_queued_job(Job *);
-static void token(Job *, FILE *);
+static void banner(Job *, FILE *);
static void print_partial_buffer(struct job_pipe *, Job *, FILE *, size_t);
static void print_partial_buffer_and_shift(struct job_pipe *, Job *, FILE *,
size_t);
@@ -283,10 +283,10 @@ print_errors()
}
static void
-token(Job *job, FILE *out)
+banner(Job *job, FILE *out)
{
if (job->node != lastNode) {
- if (DEBUG(JOBTOKEN))
+ if (DEBUG(JOBBANNER))
(void)fprintf(out, "--- %s ---\n", job->node->name);
lastNode = job->node;
}
@@ -554,7 +554,7 @@ JobFinish(Job *job, int status)
if (WIFEXITED(status)) {
debug_printf("Process %ld exited.\n", (long)job->pid);
if (WEXITSTATUS(status) != 0) {
- token(job, stdout);
+ banner(job, stdout);
(void)fprintf(stdout, "*** Error code %d%s\n",
WEXITSTATUS(status),
(job->flags & JOB_IGNERR) ? "(ignored)" :
@@ -564,13 +564,13 @@ JobFinish(Job *job, int status)
status = 0;
}
} else if (DEBUG(JOB)) {
- token(job, stdout);
+ banner(job, stdout);
(void)fprintf(stdout,
"*** Completed successfully\n");
}
} else if (WIFSTOPPED(status)) {
debug_printf("Process %ld stopped.\n", (long)job->pid);
- token(job, stdout);
+ banner(job, stdout);
(void)fprintf(stdout, "*** Stopped -- signal %d\n",
WSTOPSIG(status));
job->flags |= JOB_RESUME;
@@ -585,7 +585,7 @@ JobFinish(Job *job, int status)
* child.
*/
if (job->flags & (JOB_RESUME|JOB_RESTART)) {
- token(job, stdout);
+ banner(job, stdout);
(void)fprintf(stdout, "*** Continued\n");
}
if (!(job->flags & JOB_CONTINUING)) {
@@ -616,7 +616,7 @@ JobFinish(Job *job, int status)
(void)fflush(stdout);
return;
} else {
- token(job, stdout);
+ banner(job, stdout);
(void)fprintf(stdout, "*** Signal %d\n",
WTERMSIG(status));
}
@@ -723,7 +723,7 @@ JobExec(Job *job)
* banner with their name in it never appears). This is an attempt to
* provide that feedback, even if nothing follows it.
*/
- token(job, stdout);
+ banner(job, stdout);
setup_engine();
@@ -1023,13 +1023,13 @@ JobStart(GNode *gn, /* target to create */
/* Helper functions for JobDoOutput */
/* output debugging token and print characters from 0 to endpos */
static void
print_partial_buffer(struct job_pipe *p, Job *job, FILE *out, size_t endPos)
{
size_t i;
- token(job, out);
+ banner(job, out);
for (i = 0; i < endPos; i++)
putc(p->buffer[i], out);
}
@@ -1023,13 +1023,13 @@ JobStart(GNode *gn, /* target to create */
/* Helper functions for JobDoOutput */
-/* output debugging token and print characters from 0 to endpos */
+/* output debugging banner and print characters from 0 to endpos */
static void
print_partial_buffer(struct job_pipe *p, Job *job, FILE *out, size_t endPos)